@@ -36,7 +36,7 @@ about_cb (GtkWidget *widget, gpointer data)
 		NULL
 	};
 	/* Translator credits */
-	gchar *translator_credits = _("");
+	gchar *translator_credits = _("translator_credits");
 
 	if (about != NULL)
 	{
@@ -50,7 +50,7 @@ about_cb (GtkWidget *widget, gpointer data)
 				  "to xcalc"),
 				(const char **)authors,
 				(const char **)documenters,
-				(const char *)translator_credits,
+				strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
 				NULL);
 	gtk_signal_connect(GTK_OBJECT(about), "destroy",
 			   GTK_SIGNAL_FUNC(gtk_widget_destroyed), &about);
@@ -160,7 +160,7 @@ main(int argc, char *argv[])
 	}
 
         app = gnome_app_new("gcalc", _("GNOME Calculator"));
-	gtk_window_set_wmclass (GTK_WINDOW (app), "gcalc", "gcalc");
+	gtk_window_set_wmclass (GTK_WINDOW (app), "gnome-calculator", "gnome-calculator");
 	gtk_window_set_policy (GTK_WINDOW (app), FALSE, TRUE, FALSE);
 
         gtk_signal_connect(GTK_OBJECT(app), "delete_event",
