@@ -383,7 +383,7 @@ set_result(GnomeCalc *gc)
 		return;
 
 	gc->_priv->result = stack->d.number;
-
+	
         /* make sure put values in a consistent manner */
 	/* XXX: perhaps we can make sure the calculator works on all locales,
 	 * but currently it will lose precision if we don't do this */
@@ -442,15 +442,30 @@ convert_num(gdouble num, GnomeCalcMode from, GnomeCalcMode to)
 {
 	if(to==from)
 		return num;
-	else if(from==GNOME_CALC_DEG)
-		if(to==GNOME_CALC_RAD)
+	else if(from==GNOME_CALC_DEG) {
+		if(to==GNOME_CALC_RAD) {
+			if (fabs (num - 90) < 0.000001)
+				return M_PI_2;
+			else if (fabs (num - 180) < 0.000001)
+				return M_PI;
+			else if (fabs (num - 45) < 0.000001)
+				return M_PI_4;
+			else if (fabs (num - 360) < 0.000001)
+				return 2*M_PI;
 			return (num*M_PI)/180;
-		else /*GRAD*/
+		} else /*GRAD*/
 			return (num*200)/180;
+	}
 	else if(from==GNOME_CALC_RAD)
-		if(to==GNOME_CALC_DEG)
+		if(to==GNOME_CALC_DEG) {
+			if (num == M_PI)
+				return 180;
+			else if (num == M_PI_2)
+				return 90;
+			else if (num == M_PI_4)
+				return 45;
 			return (num*180)/M_PI;
-		else /*GRAD*/
+		} else /*GRAD*/
 			return (num*200)/M_PI;
 	else /*GRAD*/
 		if(to==GNOME_CALC_DEG)
@@ -511,13 +526,13 @@ simple_func(GtkWidget *w, gpointer data)
 		unselect_invert(gc);
 		return;
 	}
-
+	
 	/*only convert non inverting functions*/
 	if(!gc->_priv->invert && but->convert_to_rad)
 		stack->d.number = convert_num(stack->d.number,
 					      gc->_priv->mode,
 					      GNOME_CALC_RAD);
-
+	
 	errno = 0;
 	{
 		sighandler_t old = signal(SIGFPE,sigfpe_handler);
@@ -527,20 +542,20 @@ simple_func(GtkWidget *w, gpointer data)
 			stack->d.number = (*invfunc)(stack->d.number);
 		signal(SIGFPE,old);
 	}
-
+	
 	if(errno>0 ||
 	   finite(stack->d.number)==0) {
 		errno = 0;
 		do_error(gc);
 		return;
 	}
-
+	
 	/*we are converting back from rad to mode*/
 	if(gc->_priv->invert && but->convert_to_rad)
 		stack->d.number = convert_num(stack->d.number,
 					      GNOME_CALC_RAD,
 					      gc->_priv->mode);
-
+	
 	set_result(gc);
 
 	unselect_invert(gc);
@@ -758,7 +773,8 @@ negate_val(GtkWidget *w, gpointer data)
 		else
 			*p='-';
 	} else {
-		if(gc->_priv->result_string[0]=='-')
+		if(gc->_priv->result_string[0]=='-' || 
+		   gc->_priv->result == 0)
 			gc->_priv->result_string[0]=' ';
 		else
 			gc->_priv->result_string[0]='-';
@@ -1061,6 +1077,27 @@ sub_parenth(GtkWidget *w, gpointer data)
 	unselect_invert(gc);
 }
 
+static double
+sin_helper (double value)
+{
+	double ret = sin (value);
+	
+	if (fabs (ret) <= sin (M_PI)) 
+		return 0.0;
+	else
+		return ret;
+}
+
+static double
+cos_helper (double value)
+{
+	double ret = cos (value);
+	if (fabs (ret) <= cos (M_PI_2))
+		return 0.0;
+	else
+		return ret;
+}
+
 static const CalculatorButton buttons[8][5] = {
 	{
 		{N_("1/x"),  (GtkSignalFunc)simple_func, c_inv,  NULL,   FALSE, {0}, N_("Inverse"), NULL },
@@ -1070,8 +1107,8 @@ static const CalculatorButton buttons[8][5] = {
 		{N_("AC"),   (GtkSignalFunc)reset_calc,  NULL,   NULL,   FALSE, {'a','A', GDK_Escape, 0}, N_("Reset"), NULL }
 	},{
 		{N_("INV"),  NULL,                       NULL,   NULL,   FALSE, {'i','I',0}, N_("Shift"), NULL }, /*inverse button*/
-		{N_("sin"),  (GtkSignalFunc)simple_func, sin,    asin,   TRUE,  {'s','S',0}, N_("Sine"), NULL },
-		{N_("cos"),  (GtkSignalFunc)simple_func, cos,    acos,   TRUE,  {'c','C',0}, N_("Cosine"), NULL },
+		{N_("sin"),  (GtkSignalFunc)simple_func, sin_helper, asin, TRUE,{'s','S',0}, N_("Sine"), NULL },
+		{N_("cos"),  (GtkSignalFunc)simple_func, cos_helper, acos, TRUE,{'c','C',0}, N_("Cosine"), NULL },
 		{N_("tan"),  (GtkSignalFunc)simple_func, tan,    atan,   TRUE,  {'t','T',0}, N_("Tangent"), NULL },
 		{N_("DEG"),  (GtkSignalFunc)drg_toggle,  NULL,   NULL,   FALSE, {'d','D',0}, N_("Switch degrees / radians / grad"), NULL }
 	},{
@@ -1153,7 +1190,7 @@ create_button(GnomeCalc *gc, GtkWidget *table, int x, int y)
 	}
 
 	if (but->tooltip != NULL) {
-		gtk_tooltips_set_tip(GTK_TOOLTIPS(gc->_priv->tooltips), w, but->tooltip, but->tooltip_private);
+		gtk_tooltips_set_tip(GTK_TOOLTIPS(gc->_priv->tooltips), w, _(but->tooltip), but->tooltip_private);
 	}
 
 	gtk_object_set_user_data(GTK_OBJECT(w),gc);
