@@ -1,4 +1,4 @@
-/* $Id: gdict-defbox.c,v 1.15 2001/12/04 23:10:56 kevinv Exp $ */
+/* $Id: gdict-defbox.c,v 1.17 2001/12/14 00:51:44 kevinv Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -628,8 +628,16 @@ def_error_cb (dict_command_t *command, DictStatusCode code,
     defbox = GTK_OBJECT (data);
     
     if (code != DICT_SOCKET_ERROR) {
+        GtkWidget *dialog;
+        
         string = g_strdup_printf (_("Error invoking query: %s"), message);
-        gnome_error_dialog (string);
+        dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
+                                  	 GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
+                                  	 "%s", string, NULL); 
+	gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_destroy (dialog);
+	
+	g_free (string);
         sec_cmd = dict_disconnect_command_new ();
         dict_command_invoke (sec_cmd, command->context);
         
