@@ -1,4 +1,4 @@
-/* $Id: main.c,v 1.24 2001/12/05 22:38:30 kevinv Exp $ */
+/* $Id: main.c,v 1.27 2002/02/02 21:32:31 kevinv Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -80,14 +80,8 @@ int main (int argc, char *argv[])
     gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gdict.png");
     gdict_app_create (FALSE);
     gdict_pref_load ();
-    if (gdict_init_context () < 0)
-      {
-            GtkWidget *dialog = gnome_error_dialog (_("Couldn't start the dictionary; most likely, http://www.dict.org could not be contacted."));
-            gnome_dialog_run (GNOME_DIALOG (dialog));
-	    return 1;
-      }
-    /* If we can not find the context then we may as well just quit
-     * since nothing is usable anymore. But not if we're an applet */
+
+    gdict_init_context ();
     defbox->context = context;
 
     for (i = 1;  i < argc;  i++)
@@ -99,7 +93,6 @@ int main (int argc, char *argv[])
     gtk_widget_show(gdict_app);
     gtk_main();
     
-    gdict_pref_save();
     dict_context_destroy (context); /* FIXME */
 
     return 0;
